import argparse
import sys
from pathlib import Path

from batch_relpath.relpath import BatchRelpath


def main() -> None:
    """Print the relative file path to given paths from an optional
    starting point.
    """
    try:
        parser = argparse.ArgumentParser(
            description=(
                "Print the relative file path to given paths "
                "from an optional starting point."
            ),
            formatter_class=argparse.MetavarTypeHelpFormatter,
        )
        parser.add_argument(
            "path",
            type=Path,
            nargs="+",
            help="absolute or relative paths to compare",
        )
        parser.add_argument(
            "-s",
            "--start",
            type=Path,
            default=Path.cwd(),
            help="start location (default: cwd)",
        )

        args = parser.parse_args()
        start = args.start
        paths = args.path

        print(BatchRelpath(paths, start))

    except Exception as e:
        print(str(e))
        sys.exit(2)


if __name__ == "__main__":
    main()
